@@ -6,7 +6,10 @@
 #define CLANG_CONFIG_H
 
 /* Bug report URL. */
-#define BUG_REPORT_URL ""
+#define BUG_REPORT_URL "https://github.com/llvm/llvm-project/issues/"
+
+/* Default to -fPIE and -pie on Linux. */
+#define CLANG_DEFAULT_PIE_ON_LINUX 0
 
 /* Default linker to use. */
 #define CLANG_DEFAULT_LINKER ""
@@ -18,11 +21,14 @@
 /* #undef CLANG_DEFAULT_STD_CXX */
 
 /* Default C++ stdlib to use. */
-#define CLANG_DEFAULT_CXX_STDLIB "libstdc++"
+#define CLANG_DEFAULT_CXX_STDLIB ""
 
 /* Default runtime library to use. */
 #define CLANG_DEFAULT_RTLIB ""
 
+/* Default unwind library to use. */
+#define CLANG_DEFAULT_UNWINDLIB ""
+
 /* Default objcopy to use */
 #define CLANG_DEFAULT_OBJCOPY "objcopy"
 
@@ -32,6 +38,9 @@
 /* Default architecture for OpenMP offloading to Nvidia GPUs. */
 #define CLANG_OPENMP_NVPTX_DEFAULT_ARCH "sm_35"
 
+/* Default architecture for SystemZ. */
+#define CLANG_SYSTEMZ_DEFAULT_ARCH "z10"
+
 /* Multilib suffix for libdir. */
 #define CLANG_LIBDIR_SUFFIX ""
 
@@ -54,14 +63,11 @@
 /* Define if we have libxml2 */
 #define CLANG_HAVE_LIBXML 1
 
-/* Define if we have z3 and want to build it */
-/* #undef CLANG_ANALYZER_WITH_Z3 */
-
 /* Define if we have sys/resource.h (rlimits) */
 #define CLANG_HAVE_RLIMITS 1
 
 /* The LLVM product name and version */
-#define BACKEND_PACKAGE_STRING "LLVM 8.0.1"
+#define BACKEND_PACKAGE_STRING "LLVM 14.0.6"
 
 /* Linker version detected at compile time. */
 /* #undef HOST_LINK_VERSION */
@@ -70,14 +76,17 @@
 /* #undef ENABLE_LINKER_BUILD_ID */
 
 /* enable x86 relax relocations by default */
-#define ENABLE_X86_RELAX_RELOCATIONS 0
+#define ENABLE_X86_RELAX_RELOCATIONS 1
 
-/* Enable the experimental new pass manager by default */
-#define ENABLE_EXPERIMENTAL_NEW_PASS_MANAGER 0
+/* Enable IEEE binary128 as default long double format on PowerPC Linux. */
+#define PPC_LINUX_DEFAULT_IEEELONGDOUBLE 0
 
 /* Enable each functionality of modules */
-#define CLANG_ENABLE_ARCMT 0
-#define CLANG_ENABLE_OBJC_REWRITER 0
-#define CLANG_ENABLE_STATIC_ANALYZER 0
+#define CLANG_ENABLE_ARCMT 1
+#define CLANG_ENABLE_OBJC_REWRITER 1
+#define CLANG_ENABLE_STATIC_ANALYZER 1
+
+/* Spawn a new process clang.exe for the CC1 tool invocation, when necessary */
+#define CLANG_SPAWN_CC1 0
 
 #endif
